import pandas as pd


# fields found and their corresponding action
fields: list[list[str]] = [
    ["Image Type", "one_hot_encoding_from_array"],
    ["Manufacturer", "one_hot_encoding_from_str_col"],
    ["Diffusionb-value", "keep"],
    ["Diffusionb-valueMax", "keep"],
    ["Echo Number(s)", "keep"],
    ["Echo Time", "keep"],
    ["Echo Train Length", "keep"],
    ["Flip Angle", "keep"],
    ["Inversion Time", "keep"],
    ["Pixel Bandwidth", "keep"],
    ["Repetition Time", "keep"],
    ["SAR", "keep"],
    ["Scanning Sequence", "one_hot_encoding_from_array"],
    ["Sequence Variant", "one_hot_encoding_from_array"],
    ["SeriesVolumeCount", "keep"],
    ["In-plane Phase Encoding Direction", "one_hot_encoding_from_str_col"],
    ["dB/dt", "keep"],
    ["Imaging Frequency", "keep"],
    ["MR Acquisition Type", "one_hot_encoding_from_str_col"],
    ["Number of Averages", "keep"],
    ["Samples per Pixel", "keep"],
    ["Variable Flip Angle Flag", "one_hot_encoding_from_str_col"],
    ["FileName", "keep"],
    ["Image Orientation (Patient)", "keep"],
    ["Contrast/Bolus Agent", "keep"],
    ["SeriesInstanceUID", "keep"],
    ["SeriesNumber", "keep"],
    ["StudyInstanceUID", "keep"],
    ["Angio Flag", "keep"],
    ["Slice Thickness", "keep"],
    ["Pixel Spacing", "keep"],
    ["Spacing Between Slices", "keep"],
]

dropped: list[list[str]] = []

header_df: pd.DataFrame = pd.DataFrame(fields, columns=["header_name", "action"])


def get_header_df() -> pd.DataFrame:
    return header_df


# other features found during analysis and deemed not useful in the training
# dropped_fields: list[list[str]] = [
#     ["EchoTime", "drop"],
#     ["PixelBandwidth", "drop"],
#     ["Diffusion b-value", "drop"],
#     ["Temporal Resolution", "drop"],
#     ["Scan Options", "drop"],
#     ["Pixel Padding Value", "drop"],
#     ["Columns", "drop"],
#     ["Imaged Nucleus", "drop"],
#     ["Derivation Description", "drop"],
#     ["Time of Secondary Capture", "drop"],
#     ["Number of Temporal Positions", "drop"],
#     ["[NumberOfImagesInMosaic]", "drop"],
#     ["[DiffusionGradientDirection]", "drop"],
#     ["Spatial Resolution", "drop"],
#     ["ImageTypeADC", "drop"],
#     ["ImageTypeTrace", "drop"],
#     ["ManufacturerCode", "drop"],
#     ["Unnamed: 0", "drop"],
#     ["[A Coord of Top Right Corner]", "drop"],
#     ["[Acquisition Duration]", "drop"],
#     ["[AcquisitionMatrixText]", "drop"],
#     ["[Actual receive gain digital]", "drop"],
#     ["[Additional Asset Data]", "drop"],
#     ["[Advantage comp. Underflow]", "drop"],
#     ["[Asset R Factors]", "drop"],
#     ["[Auto Prescan Center Frequency]", "drop"],
#     ["[Auto Prescan Transmit Gain]", "drop"],
#     ["[Auto window/level beta]", "drop"],
#     ["[Auto window/level window]", "drop"],
#     ["[BandwidthPerPixelPhaseEncode]", "drop"],
#     ["[Bitmap of prescan options]", "drop"],
#     ["[Cardiac phase number]", "drop"],
#     ["[Cardiac Sync]", "drop"],
#     ["[Center freq. Method]", "drop"],
#     ["[Center S coord of plane image]", "drop"],
#     ["[Chemical Shift]", "drop"],
#     ["[CoilString]", "drop"],
#     ["[Content Qualification]", "drop"],
#     ["[CSA Image Header Type]", "drop"],
#     ["[CSA Image Header Version]", "drop"],
#     ["[CSA Series Header Version]", "drop"],
#     ["[DB/dt Peak rate of change of gradient field]", "drop"],
#     ["[Delay after trigger]", "drop"],
#     ["[Diffusion Direction AP]", "drop"],
#     ["[Diffusion Direction RL]", "drop"],
#     ["[Diffusion Direction]", "drop"],
#     ["[DiffusionDirectionality]", "drop"],
#     ["[Dynamic Series]", "drop"],
#     ["[Echo Train Length]", "drop"],
#     ["[EPI Factor]", "drop"],
#     ["[Exam Record checksum]", "drop"],
#     ["[Extremity Coil flag]", "drop"],
#     ["[Filter Mode (String slop field 1 in legacy GE MR]", "drop"],
#     ["[First scan ras]", "drop"],
#     ["[FlowCompensation]", "drop"],
#     ["[Foreign Image Revision]", "drop"],
#     ["[Fractional echo]", "drop"],
#     ["[GE Coil Name]", "drop"],
#     ["[Genesis Version - now]", "drop"],
#     ["[Governing Body, dB/dt, and SAR definition]", "drop"],
#     ["[Gradient offset in Y]", "drop"],
#     ["[GradientMode]", "drop"],
#     ["[Horiz. Frame of ref.]", "drop"],
#     ["[Image actual date]", "drop"],
#     ["[Image dimension - X]", "drop"],
#     ["[Image Enhanced]", "drop"],
#     ["[Image Filtering Parameters]", "drop"],
#     ["[Image location]", "drop"],
#     ["[Image Type ED ES]", "drop"],
#     ["[Images in Series]", "drop"],
#     ["[Imaging Frequency]", "drop"],
#     ["[Imaging Options]", "drop"],
#     ["[Indicates no. of updates to header]", "drop"],
#     ["[Institution Code]", "drop"],
#     ["[Internal Pulse Sequence Name]", "drop"],
#     ["[Landmark Counter]", "drop"],
#     ["[Last pseq]", "drop"],
#     ["[Last scan loc]", "drop"],
#     ["[Level value]", "drop"],
#     ["[Locs per 3D slab]", "drop"],
#     ["[Lower range of Pixels2]", "drop"],
#     ["[MedCom OOG Type]", "drop"],
#     ["[Mobile location number]", "drop"],
#     ["[MosaicRefAcqTimes]", "drop"],
#     ["[NEW/SEEN Status]", "drop"],
#     ["[None, None, None, None, None, None, None, None, None, None", "drop"],
#     ["[Normal R coord]", "drop"],
#     ["[Num 3D slabs]", "drop"],
#     ["[Number of Averages]", "drop"],
#     ["[Number of Dynamic Scans]", "drop"],
#     ["[Number of Echoes]", "drop"],
#     ["[Number of Excitations]", "drop"],
#     ["[Number of Locations]", "drop"],
#     ["[Number of Phases MR]", "drop"],
#     ["[Number of Stacks]", "drop"],
#     ["[Offset Frequency]", "drop"],
#     ["[Partial Matrix Scanned]", "drop"],
#     ["[Patient's Name]", "drop"],
#     ["[Pause Interval]", "drop"],
#     ["[PC Velocity]", "drop"],
#     ["[Phase Contrast flow axis]", "drop"],
#     ["[Phase Number]", "drop"],
#     ["[PMTF Information 1]", "drop"],
#     ["[PMTF Information 3]", "drop"],
#     ["[PositivePCSDirections]", "drop"],
#     ["[Prepulse Type]", "drop"],
#     ["[Prescan status]", "drop"],
#     ["[Primary Receiver Suite and Host]", "drop"],
#     ["[Private In-Plane Phase Encoding Direction]", "drop"],
#     ["[Projection Algorithm Name]", "drop"],
#     ["[Projection angle]", "drop"],
#     ["[PSD estimated limit in tesla per second]", "drop"],
#     ["[Pulse Sequence Date]", "drop"],
#     ["[Pulse Sequence Name]", "drop"],
#     ["[PURE Acquisition Calibration Series UID]", "drop"],
#     ["[R Coord of Top Right Corner]", "drop"],
#     ["[Raw data run number]", "drop"],
#     ["[RBMoCoTrans]", "drop"],
#     ["[Reason for Study]", "drop"],
#     ["[Receive Origin Description]", "drop"],
#     ["[Receive Time]", "drop"],
#     ["[Reconstruction Number MR]", "drop"],
#     ["[Repetition Time]", "drop"],
#     ["[Respiration Sync]", "drop"],
#     ["[Respiratory trigger point]", "drop"],
#     ["[Rotation from source y rot]", "drop"],
#     ["[RTIA_timer]", "drop"],
#     ["[S Coord of Bottom Right Corner]", "drop"],
#     ["[Sampling Percent]", "drop"],
#     ["[SAR value]", "drop"],
#     ["[SAT fat/water/bone]", "drop"],
#     ["[SAT location F]", "drop"],
#     ["[SAT location L]", "drop"],
#     ["[SAT location R]", "drop"],
#     ["[SAT thickness H/F]", "drop"],
#     ["[Saturation planes]", "drop"],
#     ["[Scanner Study ID]", "drop"],
#     ["[Scanning Technique Description MR]", "drop"],
#     ["[Screen Format]", "drop"],
#     ["[Series Complete Flag]", "drop"],
#     ["[Series from which Prescribed]", "drop"],
#     ["[Series Owner]", "drop"],
#     ["[Series Record checksum]", "drop"],
#     ["[Series Workflow Status]", "drop"],
#     ["[Slice Number MR]", "drop"],
#     ["[SliceMeasurementDuration]", "drop"],
#     ["[SliceResolution]", "drop"],
#     ["[Slop_int_6... slop_int_9]", "drop"],
#     ["[SPIR]", "drop"],
#     ["[String slop field 2]", "drop"],
#     ["[Suite id]", "drop"],
#     ["[Surface Coil Type]", "drop"],
#     ["[Syncra Scan Type]", "drop"],
#     ["[Table delta]", "drop"],
#     ["[Tag Spacing]", "drop"],
#     ["[Tagging Orientation]", "drop"],
#     ["[Tamar Site Id]", "drop"],
#     ["[Tamar Study Body Part]", "drop"],
#     ["[Tamar Study Status]", "drop"],
#     ["[Thickness disclaimer]", "drop"],
#     ["[Transmit gain]", "drop"],
#     ["[Type of receiver used]", "drop"],
#     ["[Upper range of Pixels1]", "drop"],
#     ["[User data 0]", "drop"],
#     ["[User data 10]", "drop"],
#     ["[User data 12]", "drop"],
#     ["[User data 14]", "drop"],
#     ["[User data 16]", "drop"],
#     ["[User data 18]", "drop"],
#     ["[User data 2]", "drop"],
#     ["[User data 21]", "drop"],
#     ["[User data 23 {# DTI Diffusion Dir., release 9.0 & below}]", "drop"],
#     ["[User data 25...User data 48 {User48=Effective Resolution for spiral}]", "drop"],
#     ["[User data 4]", "drop"],
#     ["[User data 6]", "drop"],
#     ["[User data 8]", "drop"],
#     ["[User_fill_map_LSW]", "drop"],
#     ["[User_usage_tag]", "drop"],
#     ["[Vas collapse flag]", "drop"],
#     ["[Velocity Encode Scale]", "drop"],
#     ["[Version of the hdr struct]", "drop"],
#     ["[Water Fat Shift]", "drop"],
#     ["[Window value]", "drop"],
#     ["Accession Number", "drop"],
#     ["Acquisition Number", "drop"],
#     ["Bits Allocated", "drop"],
#     ["Blue Palette Color Lookup Table Descriptor", "drop"],
#     ["Cardiac Number of Images", "drop"],
#     ["Coding Scheme Designator", "drop"],
#     ["Concatenation UID", "drop"],
#     ["Contrast/Bolus Ingredient", "drop"],
#     ["Contrast/Bolus Total Dose", "drop"],
#     ["Conversion Type", "drop"],
#     ["Corrected Image", "drop"],
#     ["Date of Last Calibration", "drop"],
#     ["Decay Correction", "drop"],
#     ["Diffusionb-valueCount", "drop"],
#     ["Diffusionb-valueSet", "drop"],
#     ["Frame of Reference UID", "drop"],
#     ["Green Palette Color Lookup Table Descriptor", "drop"],
#     ["HasDiffusionGradientOrientation", "drop"],
#     ["High R-R Value", "drop"],
#     ["Image Index", "drop"],
#     ["Image Position", "drop"],
#     ["ImageOrientationPatient", "drop"],
#     ["ImageOrientationPatient_1", "drop"],
#     ["ImageOrientationPatient_3", "drop"],
#     ["ImageOrientationPatient_5", "drop"],
#     ["Intervals Acquired", "drop"],
#     ["IsDerivedImageType", "drop"],
#     ["Laterality", "drop"],
#     ["Low R-R Value", "drop"],
#     ["Modality", "drop"],
#     ["Names of Intended Recipients of Results", "drop"],
#     ["Number of Phase Encoding Steps", "drop"],
#     ["Number of Study Related Instances", "drop"],
#     ["Order Entered By", "drop"],
#     ["Overlay Bits Allocated", "drop"],
#     ["Overlay Description", "drop"],
#     ["Overlay Rows", "drop"],
#     ["Palette Color Lookup Table UID", "drop"],
#     ["Percent Phase Field of View", "drop"],
#     ["Performed Procedure Step Description", "drop"],
#     ["Performed Procedure Step Status", "drop"],
#     ["Photometric Interpretation", "drop"],
#     ["Pixel Representation", "drop"],
#     ["PixelSpacingMin", "drop"],
#     ["Planar Configuration", "drop"],
#     ["Presentation LUT Shape", "drop"],
#     ["Protocol Name", "drop"],
#     ["Receive Coil Name", "drop"],
#     ["Red Palette Color Lookup Table Descriptor", "drop"],
#     ["Requested Contrast Agent", "drop"],
#     ["Requested Procedure ID", "drop"],
#     ["Requested Procedure Priority", "drop"],
#     ["Rescale Intercept", "drop"],
#     ["Rescale Type", "drop"],
#     ["Scatter Correction Method", "drop"],
#     ["Series Type", "drop"],
#     ["Software Versions", "drop"],
#     ["Special Needs", "drop"],
#     ["Stack ID", "drop"],
#     ["Study Priority ID", "drop"],
#     ["Study Read Time", "drop"],
#     ["Synchronization Frame of Reference UID", "drop"],
#     ["Transmit Coil Name", "drop"],
#     ["Units", "drop"],
#     ["Window Width", "drop"],
# ]
